import React from 'react';
import { View, Text, TouchableOpacity } from 'react-native';
import 'react-native-svg';
import { CloseIcon } from '../../assets/svgs/CloseIcon.js';
import { useBaseStyles } from './styles.js';
import { useToastContext } from '../../contexts/toast-context.js';

const BaseToast = (props) => {
    const { color, iconElement, title, message, onClose, onPress, renderIcon, renderTitle, renderMessage, renderCloseButton, } = props;
    const { colors } = useToastContext();
    const styles = useBaseStyles(colors.background, colors.leftBorder, colors.title, colors.message);
    const baseStyle = [styles.base, styles.borderLeft, { borderLeftColor: color }];
    const inner = (React.createElement(View, { style: baseStyle },
        renderIcon ? (renderIcon(props)) : (React.createElement(View, { style: styles.iconContainer }, iconElement ? iconElement : React.createElement(View, { style: styles.icon }))),
        React.createElement(View, { style: styles.contentContainer },
            React.createElement(View, null,
                renderTitle
                    ? renderTitle(props)
                    : title !== undefined && (React.createElement(View, null,
                        React.createElement(Text, { style: styles.title, numberOfLines: 1 }, title))),
                renderMessage
                    ? renderMessage(props)
                    : message !== undefined && (React.createElement(View, null,
                        React.createElement(Text, { style: styles.message, numberOfLines: 2 }, message))))),
        renderCloseButton ? (renderCloseButton(props)) : (React.createElement(TouchableOpacity, { style: styles.closeButtonContainer, onPress: onClose },
            React.createElement(CloseIcon, null)))));
    if (onPress) {
        return React.createElement(TouchableOpacity, { onPress: onPress }, inner);
    }
    return inner;
};

export { BaseToast };
//# sourceMappingURL=BaseToast.js.map
