/// <reference types="react" />
import { ColorValue } from "react-native";
import { Color as SvgColor } from "react-native-svg";
export interface ToastProps {
    type?: "info" | "success" | "error" | "warning" | string;
    position?: "top" | "bottom";
    title?: string;
    message?: string;
    autoHide?: boolean;
    visibilityTime?: number;
    height?: number;
    topOffset?: number;
    bottomOffset?: number;
    friction?: number;
    onShow?: (toast: ToastProps) => void;
    onQueue?: (toast: ToastProps) => void;
    onHide?: (toast: ToastProps) => void;
    onPress?: (toast: ToastProps) => void;
}
export interface ToastProviderProps {
    defaults?: ToastProps;
    colors?: ToastColors;
    customToasts?: ToastComponentsConfig;
    renderToaster?: boolean;
}
export interface UseToastHook {
    showToast: (props: ToastProps) => void;
    queueToast: (props: ToastProps) => void;
    hideToast: () => void;
    clearToastQueue: () => void;
}
export interface IToastContext extends ToastContextSettings, UseToastHook {
    toasts: Readonly<ToastProps[]>;
    activeToast?: ToastProps | null;
}
declare type OptionalSettings = Pick<ToastProps, "title" | "message" | "onShow" | "onQueue" | "onHide" | "onPress">;
interface ToastContextSettings {
    colors: Required<ToastColors>;
    customToasts?: ToastComponentsConfig;
    defaults: Required<Omit<ToastProps, keyof OptionalSettings>> & OptionalSettings;
}
export declare type Color = ColorValue & SvgColor;
export interface ToastColors {
    background?: Color;
    leftBorder?: Color;
    title?: Color;
    message?: Color;
    closeIcon?: Color;
    info?: Color;
    error?: Color;
    warning?: Color;
    success?: Color;
}
export interface ToastComponentsConfig {
    [x: string]: (toast: BaseToastProps) => React.ReactElement;
}
export interface SvgProps {
    color?: Color;
    size?: number;
}
export interface BaseToastProps extends ToastProps {
    color?: Color;
    iconElement?: React.ReactNode;
    onClose: () => void;
    renderIcon?: (toast: BaseToastProps) => React.ReactNode;
    renderTitle?: (toast: BaseToastProps) => React.ReactNode;
    renderMessage?: (toast: BaseToastProps) => React.ReactNode;
    renderCloseButton?: (toast: BaseToastProps) => React.ReactNode;
}
export declare type Toaster = React.FC;
export {};
//# sourceMappingURL=index.d.ts.map